@@ -1,4 +1,4 @@
-# $Id: P10.pm,v 1.1.1.1 2006/04/07 20:15:31 fil Exp $
+# $Id: P10.pm,v 1.2 2006/04/12 08:13:22 fil Exp $
 package t::P10;
 use strict;
 
@@ -45,6 +45,15 @@ sub die_for_your_country
 __END__
 
 $Log: P10.pm,v $
+Revision 1.2  2006/04/12 08:13:22  fil
+Added documentation
+Added __callback_argument and __postback_arguement
+Use Scalar::Util::reftype instead of ref()
+Added __package_register
+Added PoCo::Generic::Net::SSH2->exec and ->cmd
+Fixed PoCo::Generic::Object->DESTROY
+Added test cases to improve test coverage
+
 Revision 1.1.1.1  2006/04/07 20:15:31  fil
 Log
 
